==> quarkus-kubernetes-deployment-2.16.0.Final-sources.jar: io/quarkus/kubernetes/deployment/IngressConfig$$accessor.java <==
package io.quarkus.kubernetes.deployment;
public final class IngressConfig$$accessor {
    private IngressConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static boolean get_expose(Object __instance) {
        return ((IngressConfig)__instance).expose;
    }
    @SuppressWarnings("unchecked")
    public static void set_expose(Object __instance, boolean expose) {
        ((IngressConfig)__instance).expose = expose;
    }
    @SuppressWarnings("unchecked")
    public static Object get_host(Object __instance) {
        return ((IngressConfig)__instance).host;
    }
    @SuppressWarnings("unchecked")
    public static void set_host(Object __instance, Object host) {
        ((IngressConfig)__instance).host = (java.util.Optional<String>)host;
    }
    @SuppressWarnings("unchecked")
    public static Object get_ingressClassName(Object __instance) {
        return ((IngressConfig)__instance).ingressClassName;
    }
    @SuppressWarnings("unchecked")
    public static void set_ingressClassName(Object __instance, Object ingressClassName) {
        ((IngressConfig)__instance).ingressClassName = (java.util.Optional<String>)ingressClassName;
    }
    @SuppressWarnings("unchecked")
    public static Object get_annotations(Object __instance) {
        return ((IngressConfig)__instance).annotations;
    }
    @SuppressWarnings("unchecked")
    public static void set_annotations(Object __instance, Object annotations) {
        ((IngressConfig)__instance).annotations = (java.util.Map<String, String>)annotations;
    }
    @SuppressWarnings("unchecked")
    public static Object get_tls(Object __instance) {
        return ((IngressConfig)__instance).tls;
    }
    @SuppressWarnings("unchecked")
    public static void set_tls(Object __instance, Object tls) {
        ((IngressConfig)__instance).tls = (java.util.Map<String, IngressTlsConfig>)tls;
    }
    @SuppressWarnings("unchecked")
    public static Object get_rules(Object __instance) {
        return ((IngressConfig)__instance).rules;
    }
    @SuppressWarnings("unchecked")
    public static void set_rules(Object __instance, Object rules) {
        ((IngressConfig)__instance).rules = (java.util.Map<String, IngressRuleConfig>)rules;
    }
}

==> quarkus-kubernetes-deployment-3.2.0.Final-sources.jar: io/quarkus/kubernetes/deployment/IngressConfig$$accessor.java <==
package io.quarkus.kubernetes.deployment;
public final class IngressConfig$$accessor {
    private IngressConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static boolean get_expose(Object __instance) {
        return ((IngressConfig)__instance).expose;
    }
    @SuppressWarnings("unchecked")
    public static void set_expose(Object __instance, boolean expose) {
        ((IngressConfig)__instance).expose = expose;
    }
    @SuppressWarnings("unchecked")
    public static Object get_host(Object __instance) {
        return ((IngressConfig)__instance).host;
    }
    @SuppressWarnings("unchecked")
    public static void set_host(Object __instance, Object host) {
        ((IngressConfig)__instance).host = (java.util.Optional<String>)host;
    }
    @SuppressWarnings("unchecked")
    public static Object get_targetPort(Object __instance) {
        return ((IngressConfig)__instance).targetPort;
    }
    @SuppressWarnings("unchecked")
    public static void set_targetPort(Object __instance, Object targetPort) {
        ((IngressConfig)__instance).targetPort = (String)targetPort;
    }
    @SuppressWarnings("unchecked")
    public static Object get_ingressClassName(Object __instance) {
        return ((IngressConfig)__instance).ingressClassName;
    }
    @SuppressWarnings("unchecked")
    public static void set_ingressClassName(Object __instance, Object ingressClassName) {
        ((IngressConfig)__instance).ingressClassName = (java.util.Optional<String>)ingressClassName;
    }
    @SuppressWarnings("unchecked")
    public static Object get_annotations(Object __instance) {
        return ((IngressConfig)__instance).annotations;
    }
    @SuppressWarnings("unchecked")
    public static void set_annotations(Object __instance, Object annotations) {
        ((IngressConfig)__instance).annotations = (java.util.Map<String, String>)annotations;
    }
    @SuppressWarnings("unchecked")
    public static Object get_tls(Object __instance) {
        return ((IngressConfig)__instance).tls;
    }
    @SuppressWarnings("unchecked")
    public static void set_tls(Object __instance, Object tls) {
        ((IngressConfig)__instance).tls = (java.util.Map<String, IngressTlsConfig>)tls;
    }
    @SuppressWarnings("unchecked")
    public static Object get_rules(Object __instance) {
        return ((IngressConfig)__instance).rules;
    }
    @SuppressWarnings("unchecked")
    public static void set_rules(Object __instance, Object rules) {
        ((IngressConfig)__instance).rules = (java.util.Map<String, IngressRuleConfig>)rules;
    }
}
